@@ -302,10 +302,16 @@ def windings_aligned(triangles, normals_compare):
     if not util.is_shape(triangles, (-1, 3, 3), allow_zeros=True):
         raise ValueError(
             'triangles must have shape (n, 3, 3), got %s' % str(triangles.shape))
+    normals_compare = np.asanyarray(normals_compare, dtype=np.float64)
 
     calculated, valid = normals(triangles)
-    difference = diagonal_dot(calculated,
-                              normals_compare[valid])
+    if normals_compare.shape == (3,):
+        # single comparison vector case
+        difference = np.dot(calculated, normals_compare)
+    else:
+        # multiple comparison case
+        difference = diagonal_dot(
+            calculated, normals_compare[valid])
 
     aligned = np.zeros(len(triangles), dtype=np.bool)
     aligned[valid] = difference > 0.0
@@ -592,7 +598,7 @@ def closest_point(triangles, points):
 
     # is the point at A
     is_a = np.logical_and(d1 < tol.zero, d2 < tol.zero)
-    if is_a.any():
+    if any(is_a):
         result[is_a] = a[is_a]
         remain[is_a] = False
 
@@ -603,7 +609,7 @@ def closest_point(triangles, points):
 
     # do the logic check
     is_b = (d3 > -tol.zero) & (d4 <= d3) & remain
-    if is_b.any():
+    if any(is_b):
         result[is_b] = b[is_b]
         remain[is_b] = False
 
@@ -612,7 +618,7 @@ def closest_point(triangles, points):
     is_ab = ((vc < tol.zero) &
              (d1 > -tol.zero) &
              (d3 < tol.zero) & remain)
-    if is_ab.any():
+    if any(is_ab):
         v = (d1[is_ab] / (d1[is_ab] - d3[is_ab])).reshape((-1, 1))
         result[is_ab] = a[is_ab] + (v * ab[is_ab])
         remain[is_ab] = False
@@ -622,14 +628,14 @@ def closest_point(triangles, points):
     d5 = np.dot(ab * cp, ones)
     d6 = np.dot(ac * cp, ones)
     is_c = (d6 > -tol.zero) & (d5 <= d6) & remain
-    if is_c.any():
+    if any(is_c):
         result[is_c] = c[is_c]
         remain[is_c] = False
 
     # check if P in edge region of AC, if so return projection of P onto AC
     vb = (d5 * d2) - (d1 * d6)
     is_ac = (vb < tol.zero) & (d2 > -tol.zero) & (d6 < tol.zero) & remain
-    if is_ac.any():
+    if any(is_ac):
         w = (d2[is_ac] / (d2[is_ac] - d6[is_ac])).reshape((-1, 1))
         result[is_ac] = a[is_ac] + w * ac[is_ac]
         remain[is_ac] = False
@@ -639,14 +645,14 @@ def closest_point(triangles, points):
     is_bc = ((va < tol.zero) &
              ((d4 - d3) > - tol.zero) &
              ((d5 - d6) > -tol.zero) & remain)
-    if is_bc.any():
+    if any(is_bc):
         d43 = d4[is_bc] - d3[is_bc]
         w = (d43 / (d43 + (d5[is_bc] - d6[is_bc]))).reshape((-1, 1))
         result[is_bc] = b[is_bc] + w * (c[is_bc] - b[is_bc])
         remain[is_bc] = False
 
     # any remaining points must be inside face region
-    if remain.any():
+    if any(remain):
         # point is inside face region
         denom = 1.0 / (va[remain] + vb[remain] + vc[remain])
         v = (vb[remain] * denom).reshape((-1, 1))
